# -------------------------------------------------------
# 			Micheal de Barra
# Project:	Bangladesh / facePaper.
# Purpose: 	Dataset and analysis for publication
# Created: 	July 3 2013
#--------------------------------------------------------


library("foreign")
library("Hmisc")
library("QuantPsyc")
library("pwr")
library("lsr")
library("stats")

###############################################
## LOADING DATA  ##############################
###############################################

facePplVar = read.table("faceData.txt") 

head(facePplVar)
summary(facePplVar)
names(facePplVar)

###############################################
## DESCRIPTIVE STATISTICS  ####################
###############################################
attach(facePplVar)
detach(facePplVar)


table(DemSex01)				
mean(AgeAtInterviewYear) 	
sd(AgeAtInterviewYear)		
prop.table(table(DEMREL))	
prop.table(table(DEMMAR))	
prop.table(table(SESELEC))	
prop.table(table(DEMEDU))	

mean(DIA.ALLZero)			
sd(DIA.ALLZero)				
mean(ARI.ALLZero)			
sd(ARI.ALLZero)				

cor.test(DIA.ALLZero,ARI.ALLZero, method = "s")	
cor.test(SES.missingMean,SES1996, method = "p")	
cor.test(SES.missingMean,DEMEDU, method = "s")	
cor.test(SES1996,DEMEDU, method = "s")			
cor.test(HousePersonDirt,SES.missingMean, method = "s")
cor.test(CurrentHealth,ARI.ALLZero, method = "s")	 
cor.test(CurrentHealth,DIA.ALLZero, method = "s")	 

###############################################
## ANALYSIS				   ####################
###############################################


## t-tests				   ####################
std <- function(x) sd(x)/sqrt(length(x))

facePplVarWomen <- subset(facePplVar, DemSex01==0)
t.test(facePplVarWomen$FemaleFaces,mu=.5)
std(facePplVarWomen$FemaleFaces)
cohensD(x = facePplVarWomen$FemaleFaces, mu = .5)
	
t.test(facePplVarWomen$MaleFaces,mu=.5)	
std(facePplVarWomen$MaleFaces)
cohensD(x = facePplVarWomen$MaleFaces, mu = .5)
# note on above: the DV in the manuscipt is "percentage of the sheets (i.e., trials) in which masculinized male faces were chosen over feminized male faces ..."  MaleFaces measures feminity pref and hence to calculate the pref for masculine male faces, the above mean is subtracted from 1.


facePplVarMen <- subset(facePplVar, DemSex01==1)
t.test(facePplVarMen$MaleFaces,mu=.5)
std(facePplVarMen$MaleFaces)
cohensD(x = facePplVarMen$MaleFaces, mu = .5)	

# note on above: see note above.
		
t.test(facePplVarMen$FemaleFaces,mu=.5)	
std(facePplVarMen$MaleFaces)	
cohensD(x = facePplVarMen$FemaleFaces, mu = .5)			

# are variances equal?
var.test(facePplVar$FemaleFaces~DemSex01) 	# yes
var.test(facePplVar$MaleFaces~DemSex01) 	# yes

t.test(facePplVar$FemaleFaces~DemSex01, var.equal = TRUE)
cohensD(x = facePplVar$FemaleFaces~DemSex01, mu = 0)			
t.test(facePplVar$MaleFaces~DemSex01, var.equal = TRUE)		
cohensD(x = facePplVar$MaleFaces~DemSex01, mu = 0)			


## regression				   ####################

fit <- lm(SexDimorph ~ DIA.ALLZero, data=facePplVar) 			
fit <- lm(SexDimorph ~ ARI.ALLZero, data=facePplVar) 			
fit <- lm(SexDimorph ~ CurrentHealth, data=facePplVar) 			
fit <- lm(SexDimorph ~ SES.missingMean, data=facePplVar) 		
fit <- lm(SexDimorph ~ SES1996, data=facePplVar) 				
fit <- lm(SexDimorph ~ HousePersonDirt, data=facePplVar) 		
fit <- lm(SexDimorph ~ DEMEDU, data=facePplVar) 				
fit <- lm(SexDimorph ~ AgeAtInterviewYear, data=facePplVar) 		
fit <- lm(SexDimorph ~ DemSex01, data=facePplVar) 				
fit <- lm(SexDimorph ~ DIA.ALLZero + DemSex01, data=facePplVar) 	

fit <- lm(SameSexFaceDiMorphPref ~ DIA.ALLZero, data=facePplVar) 			
fit <- lm(SameSexFaceDiMorphPref ~ ARI.ALLZero, data=facePplVar) 			
fit <- lm(SameSexFaceDiMorphPref ~ CurrentHealth, data=facePplVar) 		
fit <- lm(SameSexFaceDiMorphPref ~ SES.missingMean, data=facePplVar) 		
fit <- lm(SameSexFaceDiMorphPref ~ SES1996, data=facePplVar) 				
fit <- lm(SameSexFaceDiMorphPref ~ HousePersonDirt, data=facePplVar) 		
fit <- lm(SameSexFaceDiMorphPref ~ DEMEDU, data=facePplVar) 				
fit <- lm(SameSexFaceDiMorphPref ~ AgeAtInterviewYear, data=facePplVar) 	
fit <- lm(SameSexFaceDiMorphPref ~ DemSex01, data=facePplVar) 			

fit <- lm(SexDimorph ~ DIA.ALLZero + CurrentHealth + DiaByCurHealth, data=facePplVar) 		

summary(fit)
confint(fit, level=0.95)
lm.beta(fit)



detach(facePplVar)